==> gimp-plugin-registry_0.5.1.orig.tar.gz: gimp-plugin-registry_0.5.1.orig/focus-blur/focusblur-3.1.5/src/shine.h <==
/* Focus Blur -- blur with focus plug-in.
 * Copyright (C) 2002-2007 Kyoichiro Suda
 *
 * The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __FOCUSBLUR_SHINE_H__
#define __FOCUSBLUR_SHINE_H__

#include <glib/gtypes.h>
#include <libgimp/gimptypes.h>

#include "focusblurtypes.h"
#include "focusblurenums.h"


G_BEGIN_DECLS


gboolean        focusblur_shine_check_enabled   (FblurStoreParam *store);
gboolean        focusblur_shine_update          (FblurShineData **shine,
                                                 GimpDrawable    *drawable,
                                                 FblurStoreParam *store);
void            focusblur_shine_destroy         (FblurShineData **shine);
gint            focusblur_shine_get             (FblurShineData  *shine,
                                                 gint             x,
                                                 gint             y);

G_END_DECLS


#endif /* __FOCUSBLUR_SHINE_H__ */

==> gimp-plugin-registry_1.0.orig.tar.gz: gimp-plugin-registry-1.0/focus-blur/focusblur-3.2.3/src/shine.h <==
/* Focus Blur -- blur with focus plug-in.
 * Copyright (C) 2002-2007 Kyoichiro Suda
 *
 * The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __FOCUSBLUR_SHINE_H__
#define __FOCUSBLUR_SHINE_H__

#include <glib/gtypes.h>
#include <libgimp/gimptypes.h>

#include "focusblurtypes.h"
#include "focusblurenums.h"


G_BEGIN_DECLS


gboolean        focusblur_shine_update          (FblurShineData **shine,
                                                 GimpDrawable    *drawable,
                                                 FblurStoreParam *store);
void            focusblur_shine_destroy         (FblurShineData **shine);
gint            focusblur_shine_get             (FblurShineData  *shine,
                                                 gint             x,
                                                 gint             y);

static inline gboolean
focusblur_shine_check_enabled (FblurStoreParam *store)
{
  gboolean enable_shine;

  enable_shine = (store->shine_radius &&
                  (store->shine_level   >= 0.5f * 100.0f / 255)
                  ) ? TRUE : FALSE;

  return enable_shine;
}


G_END_DECLS


#endif /* __FOCUSBLUR_SHINE_H__ */
